package gov.anl.aps.dm.sync;

import com.unboundid.ldap.sdk.BindRequest;
import com.unboundid.ldap.sdk.BindResult;
import com.unboundid.ldap.sdk.LDAPConnection;
import com.unboundid.ldap.sdk.LDAPException;
import com.unboundid.ldap.sdk.SimpleBindRequest;
import com.unboundid.util.ssl.SSLUtil;
import com.unboundid.util.ssl.TrustAllTrustManager;
import java.security.GeneralSecurityException;
import java.util.logging.Level;
import java.util.logging.Logger;
import javax.net.SocketFactory;

public class LdapConn {
    LDAPConnection connection = null;
    private Logger logger;

    public LdapConn(Logger logger) {
    	this.logger = logger;
    }
    

    void connect()  {
   // Use no key manager, and trust all certificates. This would not be used
    // in non-trivial code.
    SSLUtil sslUtil = new SSLUtil(null,new TrustAllTrustManager());

    SocketFactory socketFactory;
    LDAPConnection ldapConnection = null;
    try {

      // Create the socket factory that will be used to make a secure
      // connection to the server.
      socketFactory = sslUtil.createSSLSocketFactory();
        try {
            ldapConnection = new LDAPConnection(socketFactory,"blacklab.xray.aps.anl.gov",636);
            System.out.println("seems connected "+ ldapConnection.toString());
        } catch (LDAPException ex) {
            logger.log(Level.SEVERE, null, ex);
        }

    } catch(GeneralSecurityException exception) {

      System.err.println(exception);
      System.exit(1);

    }

   try {

      String dn = "uid=dmadmin,ou=People,o=aps.anl.gov,dc=aps,dc=anl,dc=gov";
      String password = "pass";
      long maxResponseTimeMillis = 1000;

      BindRequest bindRequest = new SimpleBindRequest(dn,password);
      bindRequest.setResponseTimeoutMillis(maxResponseTimeMillis);
      BindResult bindResult = ldapConnection.bind(bindRequest);
      
      System.out.println("connected to ldap " +bindResult.toString());

    } catch(LDAPException ldapException) {

      ldapConnection.close();
      System.err.println(ldapException);
      System.exit(ldapException.getResultCode().intValue());

    }    }
    
    void close() {
        connection.close();
    }    
}
